# features


+ (?) customized help information with colorful messages
+ (?) add actions for __main__ entry, that is, run a function even without statement "import easyarg", just load the script and run the function
